/* Battle Pong - a pong game with some extra features */
/* Copyright (C) 2003 Dana Olson                                            */
/* For more info, read the LICENSE file                             */

#include "init.h"

Player Players[2];
Ball PongBall;
int numPlayers(2);
int maxPlayers(2);
SDL_Surface *screen;
SDL_Surface *scoreText[2];
TTF_Font *font;
SDL_Color txtClr = { 0x00, 0x00, 0x00, 0 };
SDL_Rect src, dest;
float timeScaler(1);
int quitFlag;
int ballType(0);

int initGame()
{
        if (SDL_Init( SDL_INIT_VIDEO | SDL_INIT_AUDIO ) < 0) {
                printf("Couldn't initialize SDL: %s\n", SDL_GetError());
                return 1;
        }

        if (initSound() != 0) {
            printf("Error during sound init.\n");
            return 1;
        }
	
	screen = SDL_SetVideoMode ( 320, 240, 0, SDL_SWSURFACE );
	SDL_ShowCursor(SDL_DISABLE);

        if (screen == NULL) {
            printf("Unable to set video mode: %s\n",SDL_GetError());
            return 1;
        }

        if (TTF_Init() < 0)
        { printf("Error initializing TTF library. %s\n",SDL_GetError());
            return 1;
        }

        font = TTF_OpenFont(FONT_NAME, 15);    //
        if ( font == NULL )
        { printf("Error loading font. %s\n", SDL_GetError());
            return 1;
        }

	maxPlayers=1;
	return 0;
}

void printVersion()
{
    SDL_version compileVersion;
    SDL_VERSION(&compileVersion);
    printf("Compiled with SDL version: %d.%d.%d\n",
        compileVersion.major,
        compileVersion.minor,
        compileVersion.patch);
}

void initPlayers()
{
        /* Set up the dimensions of the player sprites */
        Players[ONE].sprDims.x=1;    Players[ONE].sprDims.y=1; Players[ONE].sprDims.w=11; Players[ONE].sprDims.h=50;
        Players[TWO].sprDims = Players[ONE].sprDims; Players[TWO].sprDims.x=25;

        /* The width and height won't change */
        Players[ONE].location.w=Players[ONE].sprDims.w; Players[ONE].location.h=Players[ONE].sprDims.h;
        Players[TWO].location.w=Players[TWO].sprDims.w; Players[TWO].location.h=Players[TWO].sprDims.h;

        /* Set the dimensions of the paddle surface for collision detection */
        /* Try modifying the x and w coords for better collision detection??? */
		Players[ONE].dims.x = 3; Players[ONE].dims.y = 6; Players[ONE].dims.w = 8; Players[ONE].dims.h = 39;
		Players[TWO].dims = Players[ONE].dims; Players[ONE].dims.x = 27; Players[ONE].dims.y = 6;

        /* Set the starting locations for the players */
        Players[ONE].location.x=1;
        Players[ONE].location.y=(SCREEN_HIGH/2)-(Players[ONE].sprDims.h/2);

        Players[TWO].location.x=SCREEN_WIDE-Players[TWO].sprDims.w-2;
        Players[TWO].location.y=(SCREEN_HIGH/2)-(Players[TWO].sprDims.h/2);

        /* Set up the dimensions of the ball sprite */
        PongBall.sprDims.x=1+(ballType*13); PongBall.sprDims.y=114; PongBall.sprDims.w=12; PongBall.sprDims.h=12;
        PongBall.location.w=PongBall.sprDims.w; PongBall.location.h=PongBall.sprDims.h;

        /* Initialize the position of the pong ball - MOVE TO SEPARATE RESET BALL FUNCTION */
        PongBall.resetBall(INITIALDELAY+1);
}

void quitGame()
{
        Mix_CloseAudio();
        SDL_Quit();
        TTF_Quit();
        printf("SDL, SDL_mixer, and TTF have been shut down.\n");
}
